==> vgs-cli-1.7.0.tar.gz: vgs-cli-1.7.0/vgscli/auth.py <==
import os
from typing import Optional

from simple_rest_client.exceptions import ClientError

from vgscli.auth_server import AuthServer
from vgscli.errors import AuthenticationError, AuthenticationRequiredError, TokenNotValidError, \
    AutoAuthenticationError
from vgscli.keyring_token_util import KeyringTokenUtil

token_util = KeyringTokenUtil()
TOKEN_FILE_NAME = 'vgs_token'

CLIENT_ID = os.environ.get('VGS_CLIENT_ID')
CLIENT_SECRET = os.environ.get('VGS_CLIENT_SECRET')

AUTO_LOGIN = CLIENT_ID and CLIENT_SECRET


def handshake(ctx, environment):
    try:
        token_util.validate_refresh_token()
        if not token_util.validate_access_token():
            AuthServer(environment).refresh_authentication()
    except TokenNotValidError:
        raise AuthenticationRequiredError(ctx)
    except Exception as e:
        raise AuthenticationError(ctx, e.args[0])


def login(ctx, environment, idp: Optional[str] = None):
    try:
        return AuthServer(environment).login(environment, idp)
    except Exception as e:
        raise AuthenticationError(ctx, e.args[0])


def logout(ctx, environment):
    try:
        AuthServer(environment).logout()
        token_util.clear_tokens()
        token_util.remove_encryption_secret()
    except Exception as e:
        raise AuthenticationError(ctx, e.args[0])


def auto_login(ctx, environment):
    if not AUTO_LOGIN:
        return False

    if not token_util.is_access_token_valid():
        try:
            AuthServer(environment).auto_login(CLIENT_ID, CLIENT_SECRET)
        except ClientError:
            raise AutoAuthenticationError(ctx)

    return True

==> vgs-cli-1.7.2.tar.gz: vgs-cli-1.7.2/vgscli/auth.py <==
from typing import Optional

from simple_rest_client.exceptions import ClientError

from vgscli.auth_server import AuthServer
from vgscli.errors import AuthenticationError, AuthenticationRequiredError, TokenNotValidError, \
    ClientCredentialsAuthenticationError
from vgscli.keyring_token_util import KeyringTokenUtil

token_util = KeyringTokenUtil()
TOKEN_FILE_NAME = 'vgs_token'


def handshake(ctx, environment):
    try:
        token_util.validate_refresh_token()
        if not token_util.validate_access_token():
            AuthServer(environment).refresh_authentication()
    except TokenNotValidError:
        raise AuthenticationRequiredError(ctx)
    except Exception as e:
        raise AuthenticationError(ctx, e.args[0])


def login(ctx, environment, idp: Optional[str] = None):
    try:
        return AuthServer(environment).login(environment, idp)
    except Exception as e:
        raise AuthenticationError(ctx, e.args[0])


def logout(ctx, environment):
    try:
        AuthServer(environment).logout()
        token_util.clear_tokens()
        token_util.remove_encryption_secret()
    except Exception as e:
        raise AuthenticationError(ctx, e.args[0])


def client_credentials_login(ctx, client_id, client_secret, environment):
    try:
        if not token_util.is_access_token_valid() or token_util.is_access_token_azp_changed(client_id):
            AuthServer(environment).client_credentials_login(client_id, client_secret)
    except (TokenNotValidError, ClientError):
        raise ClientCredentialsAuthenticationError(ctx)

    return True
